@@ -332,6 +332,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_JUMP,
 	INTERFACEKEY_A_HOLD,
 	INTERFACEKEY_A_TALK,
+	INTERFACEKEY_A_CONV_PERSUADE,
+	INTERFACEKEY_A_CONV_INTIMIDATE,
 	INTERFACEKEY_A_ASSUME_IDENTITY_NEW,
 	INTERFACEKEY_A_ASSUME_IDENTITY_NONE,
 	INTERFACEKEY_A_ASSUME_IDENTITY_NAME,
@@ -377,6 +379,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_SHOOT,
 	INTERFACEKEY_A_ANNOUNCEMENTS,
 	INTERFACEKEY_A_COMBAT,
+	INTERFACEKEY_A_TACTICAL_SETTINGS,
 	INTERFACEKEY_A_MOVEMENT,
 	INTERFACEKEY_A_MOVEMENT_SWIM,
 	INTERFACEKEY_A_SNEAK,
@@ -392,6 +395,23 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_WEATHER,
 	INTERFACEKEY_A_TEMPERATURE,
 	INTERFACEKEY_A_STANCE,
+	INTERFACEKEY_CSHEET_BACKGROUND,
+	INTERFACEKEY_CSHEET_NEW_CHARACTER,
+	INTERFACEKEY_CSHEET_SKILLS,
+	INTERFACEKEY_CSHEET_APPEARANCE,
+	INTERFACEKEY_CSHEET_PERSONALITY,
+	INTERFACEKEY_CSHEET_EQUIPMENT,
+	INTERFACEKEY_CSHEET_PETS,
+	INTERFACEKEY_CSHEET_RANDOMIZE_BACKGROUND,
+	INTERFACEKEY_CSHEET_SELECT_BACKGROUND_OPTION,
+	INTERFACEKEY_CSHEET_WORSHIP_UP,
+	INTERFACEKEY_CSHEET_WORSHIP_DOWN,
+	INTERFACEKEY_CSHEET_NEW_ITEM,
+	INTERFACEKEY_CSHEET_QUALITY_UP,
+	INTERFACEKEY_CSHEET_QUALITY_DOWN,
+	INTERFACEKEY_CSHEET_NAME_PET,
+	INTERFACEKEY_CSHEET_REMOVE_PET,
+	INTERFACEKEY_CSHEET_ADD_PET,
 	INTERFACEKEY_A_ENTER_NAME,
 	INTERFACEKEY_A_CUST_NAME,
 	INTERFACEKEY_A_RANDOM_NAME,
@@ -405,7 +425,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_TRAVEL_CLOUDS,
 	INTERFACEKEY_A_LOG,
 	INTERFACEKEY_A_TRAVEL_LOG,
-	INTERFACEKEY_A_LOG_TASKS,
+	INTERFACEKEY_A_LOG_SORT,
+	INTERFACEKEY_A_LOG_PIN,
 	INTERFACEKEY_A_LOG_ENTITIES,
 	INTERFACEKEY_A_LOG_SITES,
 	INTERFACEKEY_A_LOG_SUBREGIONS,
@@ -415,6 +436,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_LOG_EVENTS,
 	INTERFACEKEY_A_LOG_BESTIARY,
 	INTERFACEKEY_A_LOG_ARTIFACTS,
+	INTERFACEKEY_A_LOG_INTRIGUE,
 	INTERFACEKEY_A_LOG_FILTER,
 	INTERFACEKEY_A_LOG_ZOOM_CURRENT_LOCATION,
 	INTERFACEKEY_A_LOG_ZOOM_SELECTED,
@@ -470,6 +492,7 @@ enum InterfaceKeyType
 	BUILDINGKEY_START,
 	INTERFACEKEY_BUILDJOB_ADD=BUILDINGKEY_START,
 	INTERFACEKEY_BUILDJOB_CANCEL,
+	INTERFACEKEY_BUILDJOB_NAME,
 	INTERFACEKEY_BUILDJOB_PROMOTE,
 	INTERFACEKEY_BUILDJOB_NOW,
 	INTERFACEKEY_BUILDJOB_REPEAT,
@@ -523,7 +546,6 @@ enum InterfaceKeyType
 	INTERFACEKEY_BUILDJOB_BED_DORMITORY,
 	INTERFACEKEY_BUILDJOB_BED_RENT,
 	INTERFACEKEY_BUILDJOB_BED_SIZE,
-	INTERFACEKEY_BUILDJOB_BED_NAME,
 	INTERFACEKEY_BUILDJOB_BED_SLEEP,
 	INTERFACEKEY_BUILDJOB_BED_TRAIN,
 	INTERFACEKEY_BUILDJOB_BED_INDIV_EQ,
@@ -613,6 +635,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_BUILDING_BOOKCASE,
 	INTERFACEKEY_HOTKEY_BUILDING_HIVE,
 	INTERFACEKEY_HOTKEY_BUILDING_DISPLAY_FURNITURE,
+	INTERFACEKEY_HOTKEY_BUILDING_OFFERING_PLACE,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_SCREW_PUMP,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_WATER_WHEEL,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_WINDMILL,
@@ -722,7 +745,9 @@ enum InterfaceKeyType
 	INTERFACEKEY_LOCATION_RETIRE,
 	INTERFACEKEY_LOCATION_INN_TAVERN,
 	INTERFACEKEY_LOCATION_TEMPLE,
+	INTERFACEKEY_LOCATION_RECOGNIZE_PRIESTHOOD,
 	INTERFACEKEY_LOCATION_LIBRARY,
+	INTERFACEKEY_LOCATION_GUILDHALL,
 	INTERFACEKEY_LOCATION_MAIN_HALL,
 	INTERFACEKEY_LOCATION_RENAME,
 	INTERFACEKEY_LOCATION_DETAILS,
@@ -941,6 +966,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_STOCKPILE_SETTINGS_FORBID_SUB,
 	INTERFACEKEY_STOCKPILE_SETTINGS_SPECIFIC1,
 	INTERFACEKEY_STOCKPILE_SETTINGS_SPECIFIC2,
+	INTERFACEKEY_CIVZONE_NAME,
 	INTERFACEKEY_CIVZONE_REMOVE,
 	INTERFACEKEY_CIVZONE_REMOVE_ZONE,
 	INTERFACEKEY_CIVZONE_SHAPE,
@@ -980,6 +1006,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_ANIMAL_HUNTING_TRAINING,
 	INTERFACEKEY_KITCHEN_COOK,
 	INTERFACEKEY_KITCHEN_BREW,
+	INTERFACEKEY_JUSTICE_INTERROGATE,
+	INTERFACEKEY_JUSTICE_COUNTERINTELLIGENCE,
 	INTERFACEKEY_ORDERS_AUTOFORBID,
 	INTERFACEKEY_ORDERS_FORBID_PROJECTILE,
 	INTERFACEKEY_ORDERS_FORBID_YOUR_CORPSE,
@@ -1120,6 +1148,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_D_BITEM_DUMP,
 	INTERFACEKEY_D_BITEM_MELT,
 	INTERFACEKEY_D_BITEM_HIDE,
+	INTERFACEKEY_D_BITEM_NAME,
 	INTERFACEKEY_D_LOOK_FORBID,
 	INTERFACEKEY_D_LOOK_DUMP,
 	INTERFACEKEY_D_LOOK_MELT,
@@ -1135,6 +1164,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_ARENA_CREATURE_BLANK_LIST,
 	INTERFACEKEY_ARENA_CREATURE_REMOVE_ITEM,
 	INTERFACEKEY_ARENA_CREATURE_UNDEAD,
+	INTERFACEKEY_ARENA_CREATURE_TAME,
 	INTERFACEKEY_ARENA_CREATURE_STRING,
 	INTERFACEKEY_ARENA_CONFLICT_STATE_1,
 	INTERFACEKEY_ARENA_CONFLICT_STATE_2,
@@ -1165,6 +1195,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_MILITARY_WEAPON,
 	INTERFACEKEY_MILITARY_ZOOM,
 	INTERFACEKEY_ANNOUNCE_ZOOM,
+	INTERFACEKEY_ANNOUNCE_ZOOM_2,
 	INTERFACEKEY_UNITJOB_REMOVE_CRE,
 	INTERFACEKEY_UNITJOB_ZOOM_CRE,
 	INTERFACEKEY_UNITJOB_ZOOM_BUILD,
@@ -1251,6 +1282,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_UNITVIEW_GEN_MISC,
 	INTERFACEKEY_UNITVIEW_PRF_PROF,
 	INTERFACEKEY_UNITVIEW_PRF_PET,
+	INTERFACEKEY_UNITVIEW_PRF_EXPEL,
 	INTERFACEKEY_UNITVIEW_PRF_VIEW,
 	INTERFACEKEY_UNITVIEW_PRF_NEW_SQUAD,
 	INTERFACEKEY_UNITVIEW_PRF_REMOVE_FROM_SQUAD,
@@ -1264,6 +1296,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_IMAGE_CREATOR_DONE,
 	INTERFACEKEY_CIV_RAID,
 	INTERFACEKEY_CIV_CENTER_ON_FORT,
+	INTERFACEKEY_CIV_HOLDINGS,
+	INTERFACEKEY_CIV_MAP_LEGEND,
 	INTERFACEKEY_CIV_REMOVE_MISSION,
 	INTERFACEKEY_CIV_RESCUE,
 	INTERFACEKEY_CIV_RECOVER,
@@ -1280,6 +1314,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_CIV_MISSION_RAZE,
 	INTERFACEKEY_CIV_MISSION_TRIBUTE_ONE_TIME,
 	INTERFACEKEY_CIV_MISSION_TRIBUTE_ONGOING,
+	INTERFACEKEY_CIV_MISSION_CONQUER,
+	INTERFACEKEY_CIV_MISSION_DEMAND_SURRENDER,
 	INTERFACEKEY_CIV_NEWS,
 	INTERFACEKEY_CIV_PEOPLE,
 	INTERFACEKEY_CIV_ARTIFACTS,
